==> knetdockapp_0.82.orig.tar.gz: knetdockapp-0.82/src/knetdockif.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "knetdockif.h"

KNetDockIf::KNetDockIf(QObject *parent, const char *name)
 : QObject(parent, name)
{

}


KNetDockIf::~KNetDockIf()
{
}

void KNetDockIf::initDevice(const QString& if_name)
{
	useBPS=false;
	devtype=ETHER;
	this->if_name=if_name;

	memset(&stats,0,sizeof(struct net_device_stats));
	
	oldstat.bytes=0ULL;
	oldstat.bytes_in=0ULL;
	oldstat.bytes_out=0ULL;

	oldstat.speed=0ULL;
	oldstat.speed_in=0ULL;
	oldstat.speed_out=0ULL;

	total.bytes=0ULL;
	total.bytes_in=0ULL;
	total.bytes_out=0ULL;

	total.speed=0ULL;
	total.speed_in=0ULL;
	total.speed_out=0ULL;

	addrstat.ip="N/A";
	addrstat.mask="N/A";
	addrstat.mac="N/A";

	wstat.link_qual=0;
	wstat.signal_level=0;
	wstat.noise_level=0;
	

}

==> knetdockapp_0.82.3.orig.tar.gz: knetdockapp-0.82.3/src/knetdockif.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Todor Gyumyushev   *
 *   yodor@developer.bg   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "knetdockif.h"

KNetDockIf::KNetDockIf(QObject *parent, const char *name)
 : QObject(parent, name)
{

}


KNetDockIf::~KNetDockIf()
{
}

void KNetDockIf::initDevice(const QString& if_name)
{
	useBPS=false;
	devtype=ETHER;
	this->if_name=if_name;

	memset(&stats,0,sizeof(struct rtnl_link_stats));
	
	oldstat.bytes=0ULL;
	oldstat.bytes_in=0ULL;
	oldstat.bytes_out=0ULL;

	oldstat.speed=0ULL;
	oldstat.speed_in=0ULL;
	oldstat.speed_out=0ULL;

	total.bytes=0ULL;
	total.bytes_in=0ULL;
	total.bytes_out=0ULL;

	total.speed=0ULL;
	total.speed_in=0ULL;
	total.speed_out=0ULL;

	addrstat.ip="N/A";
	addrstat.mask="N/A";
	addrstat.mac="N/A";

	wstat.link_qual=0;
	wstat.signal_level=0;
	wstat.noise_level=0;
	

}
